* Project: NVRB - Salaried Workers in Ghana
* Buehren, N., Ceretti, V., Dervisevic, E., Goldstein, M., Klapper, L., Koroknay-Palicz, T., & Schaner, S. (2018)
* Salary Delays and Overdrafts in Rural Ghana. AEA Papers and Proceedings (Vol. 108, pp. 449-52).
* Last Update: 08-17-2018

clear all
set more off
cd "~~~~~"

********************************************************************************
*********************************** TABLE 1: ***********************************
********************************************************************************
use "Salary Delays and Overdrafts_Dataset.dta", clear
* Keep labels as locals:
foreach v of var * {
        local l`v' : variable label `v'
}
* Collapse the data by month, then period:
collapse (max) overdraft_paid,  by(partid female age* salary_amt self_hh married ///
christian public_ml teacher education_less hh_memx hh_0to15x hh_65x before realmonths)
collapse (mean) overdraft_paid, by(partid female age* salary_amt self_hh married ///
christian public_ml teacher education_less hh_memx hh_0to15x hh_65x before)
* Relabel all variables:
foreach v of var * {
        label var `v' "`l`v''"
}
label var overdraft_paid "Outcome: Fraction of months in overdraft"		
********************************************************************************
eststo clear
* Linear regression with robust standard errors
eststo: reg overdraft_paid female age* salary_amt          self_hh married christian public_ml teacher education_less hh_memx hh_0to15x hh_65x if before==1, robust
		sum overdraft_paid if e(sample)==1
		estadd scalar mean = r(mean)
esttab using "Table 1.csv", ///
nonumbers nogaps compress label wrap varwidth(30) longtable ///
b(4) se(3) replace star(* 0.1 ** 0.05 *** 0.01) drop(_cons) ///
scalars("mean Mean dependent variable") sfmt(4) ///
nonotes addnotes("Notes: Heteroskedasticity robust standard errors in parentheses. Two observations are dropped due to missing baseline covariates." ///
"*p<0.1 **p<0.05 ***p<0.01") ///
title("Determinants of overdraft status with baseline data")

********************************************************************************
*********************************** TABLE 2: ***********************************
********************************************************************************
use "Salary Delays and Overdrafts_Dataset.dta", clear
* Replace real months with overdraft months, created to depend on mode of salary days for each individual:
	replace before	=1 if overmonths==646
	replace before	=0 if overmonths==647
	replace during	=0 if overmonths==646
	replace during	=1 if overmonths==647
		replace during	=1 if overmonths==664
		replace during	=0 if overmonths==665
		replace after	=0 if overmonths==664
		replace after	=1 if overmonths==665
* Keep labels as locals:
foreach v of var * {
        local l`v' : variable label `v'
}
* Collapse the data by overdraft month, then relabel:
collapse 	(max) date (sum) salaries ///
			(max) loan overdraft_paid salary_* ///
			(mean) treatment before during after Tbefore Tduring Tafter, by(partid overmonths)
foreach v of var * {
        label var `v' "`l`v''"
}
********************************************************************************
* Create a variable for salary late for last month and a dummy for 2+ salaries received:
sort partid overmonths
	gen salary_lastmonth=salary_monthlate
	replace salary_lastmonth=. if salary_prevmonth==.
	gen salaries_copy=(salaries>0 & salaries<.)			
	replace salaries=(salaries>1 & salaries<.)
********************************************************************************
* Create a variable for early end of salaries, when an individual stops receiving a salry 5 or more months prior to the last account activity:
		bysort partid: egen lastmonth=max(overmonths)
		gen nosal_end=1 if overmonths==lastmonth & salaries_copy==0
		gsort partid -overmonths
		replace nosal_end=nosal_end[_n-1] if nosal_end==. & nosal_end[_n-1]==1 & salaries_copy==0 & partid==partid[_n-1]
		recode nosal_end(.=0)
		bysort partid: egen early_end=sum(nosal_end)
		replace nosal_end=0 if early_end<5
		drop if overmonths<616 | overmonths>676
********************************************************************************
label var salaries "Two or more payments received"
label var salary_lastmonth "Last month late"
label var nosal_end "Early end of salaries"
eststo clear
xtset partid overmonths 
* Arellano-Bond and linear regressions with robust standard errors:
eststo: xtabond overdraft_paid	loan	during after Tduring Tafter 	salary_lastmonth	 						, twostep robust lags(2)
		sum overdraft_paid if e(sample)==1
		estadd scalar mean = r(mean)
eststo: xtabond overdraft_paid	loan	during after Tduring Tafter 	salary_lastmonth	salaries 	nosal_end	, twostep robust lags(2)
		sum overdraft_paid if e(sample)==1
		estadd scalar mean = r(mean)
eststo: xtreg overdraft_paid	loan	during after Tduring Tafter 	salary_lastmonth	salaries 	nosal_end	i.overmonths, fe cluster(partid) robust
		sum overdraft_paid if e(sample)==1
		estadd scalar mean = r(mean)
esttab using "Table 2.csv", ///
nonumbers nogaps compress label wrap varwidth(30) longtable ///
varlabels(L.overdraft_paid "Overdraft (lag 1)" L2.overdraft_paid "Overdraft (lag 2)") ///
b(4) se(3) replace star(* 0.1 ** 0.05 *** 0.01) drop(_cons *overmonth*) ///
order(L* during after Tduring Tafter loan *lastmonth* *salaries*) ///
scalars("mean Mean dependent variable") sfmt(4) ///
nonotes addnotes("All regressions include individual and month-year fixed effects. Robust and individual-clustered standard errors in parentheses." ///
"*p<0.1 **p<0.05 ***p<0.01") ///
title("Determinants of overdrafting behavior with monthly administrative data")
